@@ -189,10 +189,13 @@ const kameletBindings = {
         source: {
           ref: {
             kind: 'Kamelet',
-            apiVersion: 'camel.apache.org/v1alpha1',
-            name: 'timer-source',
+            apiVersion: 'camel.apache.org/v1',
+            name: 'kafka-source',
             properties: {
-              message: 'Hello',
+              bootstrapServers: 'localhost:9092',
+              topic: 'mytopic',
+              user: 'kafka',
+              password: 'kafka123!'
             },
           },
         },
